CardDetailResponse class

Constructors

CardDetailResponse({int? status, String? message, String? statusdescription, List<Result>? result, int? cardcount, String? token})
CardDetailResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cardcount int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
result List<Result>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
getter/setter pair
statusdescription String?
getter/setter pair
token String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited