Result class

Constructors

Result({String? cardtpye, String? cardstart, String? cardend, String? expiry, String? cardholder, String? carduniquecode, String? defaultCard, String? expirymonth, String? expiryyear})
Result.fromJson(Map<String, dynamic> json)
factory

Properties

cardend String?
getter/setter pair
cardholder String?
getter/setter pair
cardstart String?
getter/setter pair
cardtpye String?
getter/setter pair
carduniquecode String?
getter/setter pair
defaultCard String?
getter/setter pair
expiry String?
getter/setter pair
expirymonth String?
getter/setter pair
expiryyear String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited